#ifndef NT2_INCLUDE_FUNCTIONS_MADD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MADD_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/madd.hpp>

#endif
